@@ -27,13 +27,9 @@ use Moose;
 use Moose::Util::TypeConstraints;
 use MooseX::StrictConstructor;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
-subtype 'Chart.OFC2.Labels'
-    => as 'Object'
-    => where { $_[0]->isa('Chart::OFC2::Labels') };
-
-coerce 'Chart.OFC2.Labels'
+coerce 'Chart::OFC2::Labels'
     => from 'ArrayRef'
     => via { Chart::OFC2::Labels->new('labels' => $_) };
 
